shaker
------

The tool runs specified scenario

.. literalinclude:: tools/shaker.txt

shaker-agent
------------

.. literalinclude:: tools/shaker-agent.txt

shaker-report
-------------

.. literalinclude:: tools/shaker-report.txt

shaker-image-builder
--------------------

The tool that creates master image in OpenStack cloud.

.. literalinclude:: tools/shaker-image-builder.txt

shaker-cleanup
--------------

.. literalinclude:: tools/shaker-cleanup.txt
